@@ -13,13 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# Lint as: python3
 """TED-LIUM speech recognition dataset."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import os
 import re
 import numpy as np
@@ -32,8 +27,7 @@ import tensorflow_datasets.public_api as tfds
 class TedliumReleaseConfig(tfds.core.BuilderConfig):
   """BuilderConfig for a release of the TED-LIUM dataset."""
 
-  @tfds.core.disallow_positional_args
-  def __init__(self, url, download_url, split_paths, citation, **kwargs):
+  def __init__(self, *, url, download_url, split_paths, citation, **kwargs):
     super(TedliumReleaseConfig,
           self).__init__(version=tfds.core.Version("1.0.1"), **kwargs)
     self.url = url
@@ -150,12 +144,7 @@ def _make_builder_configs():
         }
         """,
       url="https://www.openslr.org/51/",
-      download_url=tfds.download.Resource(
-          url="http://www.openslr.org/resources/51/TEDLIUM_release-3.tgz",
-          # The blessed tarball linked above contains some invalid symlinks (for
-          # the speaker_adaptation splits) which TAR_STREAM conveniently skips
-          # over, avoiding exceptions on parts of the dataset we don't need.
-          extract_method=tfds.download.ExtractMethod.TAR_STREAM),
+      download_url="http://www.openslr.org/resources/51/TEDLIUM_release-3.tgz",
       split_paths=[
           (tfds.Split.VALIDATION,
            os.path.join("TEDLIUM_release-3", "legacy", "dev")),
