@@ -28,26 +28,18 @@ import os
 import random
 import shutil
 import string
-import sys
 import textwrap
 import threading
-import types
-from typing import Any, Callable, Iterator, List, NoReturn, TypeVar, Union
+import typing
+from typing import Any, Callable, Iterator, List, NoReturn, Tuple, Type, TypeVar, Union
 import uuid
 
 from six.moves import urllib
 import tensorflow.compat.v2 as tf
 from tensorflow_datasets.core import constants
+from tensorflow_datasets.core.utils import type_utils
 
-
-# pylint: disable=g-import-not-at-top
-if sys.version_info >= (3, 9):
-  import importlib.resources as importlib_resources
-else:
-  import importlib_resources
-
-# pylint: enable=g-import-not-at-top
-
+Tree = type_utils.Tree
 
 # NOTE: When used on an instance method, the cache is shared across all
 # instances and IS NOT per-instance.
@@ -63,7 +55,7 @@ Fn = TypeVar('Fn', bound=Callable[..., Any])
 
 
 def is_notebook():
-  """Returns True if running in a notebook (Colab, Jupyter) environement."""
+  """Returns True if running in a notebook (Colab, Jupyter) environment."""
   # Inspired from the tfdm autonotebook code
   try:
     import IPython  # pytype: disable=import-error  # pylint: disable=import-outside-toplevel,g-import-not-at-top
@@ -157,11 +149,14 @@ class memoized_property(property):  # pylint: disable=invalid-name
     return cached
 
 
-def resource_path(
-    package: Union[str, types.ModuleType]
-) -> importlib_resources.abc.Traversable:  # pytype: disable=module-attr
-  """Returns `importlib.resources.files`."""
-  return importlib_resources.files(package)  # pytype: disable=module-attr
+if typing.TYPE_CHECKING:
+  # TODO(b/171883689): There is likelly better way to annotate descriptors
+
+  def classproperty(fn: Callable[[Type[Any]], T]) -> T:  # pylint: disable=function-redefined
+    return fn(type(None))
+
+  def memoized_property(fn: Callable[[Any], T]) -> T:  # pylint: disable=function-redefined
+    return fn(None)
 
 
 def map_nested(function, data_struct, dict_only=False, map_tuple=False):
@@ -220,6 +215,40 @@ def flatten_nest_dict(d):
   return flat_dict
 
 
+# Note: Could use `tree.flatten_with_path` instead, but makes it harder for
+# users to compile from source.
+def flatten_with_path(
+    structure: Tree[T],
+) -> Iterator[Tuple[Tuple[Union[str, int], ...], T]]:  # pytype: disable=invalid-annotation
+  """Convert a TreeDict into a flat list of paths and their values.
+
+  ```py
+  flatten_with_path({'a': {'b': v}}) == [(('a', 'b'), v)]
+  ```
+
+  Args:
+    structure: Nested input structure
+
+  Yields:
+    The `(path, value)` tuple. With path being the tuple of `dict` keys and
+      `list` indexes
+  """
+  if isinstance(structure, dict):
+    key_struct_generator = sorted(structure.items())
+  elif isinstance(structure, (list, tuple)):
+    key_struct_generator = enumerate(structure)
+  else:
+    key_struct_generator = None  # End of recursion
+
+  if key_struct_generator is not None:
+    for key, sub_structure in key_struct_generator:
+      # Recurse into sub-structures
+      for sub_path, sub_value in flatten_with_path(sub_structure):
+        yield (key,) + sub_path, sub_value
+  else:
+    yield (), structure  # Leaf, yield value
+
+
 def dedent(text):
   """Wrapper around `textwrap.dedent` which also `strip()` and handle `None`."""
   return textwrap.dedent(text).strip() if text else text
@@ -348,19 +377,6 @@ def incomplete_dir(dirname):
       tf.io.gfile.rmtree(tmp_dir)
 
 
-def tfds_dir() -> str:
-  """Path to tensorflow_datasets directory.
-
-  The difference with `tfds.core.get_tfds_path` is that this function can be
-  used for write access while `tfds.core.get_tfds_path` should be used for
-  read-only.
-
-  Returns:
-    tfds_dir: The root TFDS path.
-  """
-  return os.path.dirname(os.path.dirname(os.path.dirname(__file__)))
-
-
 @contextlib.contextmanager
 def atomic_write(path, mode):
   """Writes to path atomically, by writing to temp file and renaming it."""
@@ -370,31 +386,21 @@ def atomic_write(path, mode):
   tf.io.gfile.rename(tmp_path, path, overwrite=True)
 
 
-def get_tfds_path(relative_path):
-  """Returns absolute path to file given path relative to tfds root."""
-  path = os.path.join(tfds_dir(), relative_path)
-  return path
-
-
-def get_resource_path(path) -> str:
-  """Get the read-only resource path."""
-  # For compatibility with `zip` archives, we should replace this by a pathlike
-  # abstraction, which uses `importlib.resource.files()`
-  return str(path)
-
-
-def read_checksum_digest(path, checksum_cls=hashlib.sha256):
+def read_checksum_digest(
+    path: type_utils.PathLike,
+    checksum_cls=hashlib.sha256,
+) -> Tuple[str, int]:
   """Given a hash constructor, returns checksum digest and size of file."""
   checksum = checksum_cls()
   size = 0
-  with tf.io.gfile.GFile(path, 'rb') as f:
+  with tf.io.gfile.GFile(os.fspath(path), 'rb') as f:
     while True:
       block = f.read(io.DEFAULT_BUFFER_SIZE)
       size += len(block)
       if not block:
         break
       checksum.update(block)
-  return checksum.hexdigest(), size
+  return checksum.hexdigest(), size  # base64 digest would have been better.
 
 
 def reraise(
