@@ -13,13 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# Lint as: python3
 """Tests for Cityscapes dataset module."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 from tensorflow_datasets import testing
 from tensorflow_datasets.image import cityscapes
 
@@ -54,6 +49,7 @@ class CityscapesStereoDisparityTest(testing.DatasetBuilderTestCase):
   }
 
 
+
 class CityscapesStereoDisparityExtraTest(testing.DatasetBuilderTestCase):
   DATASET_CLASS = cityscapes.Cityscapes
   BUILDER_CONFIG_NAMES_TO_TEST = ['stereo_disparity_extra']
