@@ -21,7 +21,7 @@ import os
 import tensorflow.compat.v2 as tf
 import tensorflow_datasets.public_api as tfds
 
-_URL = "https://nextcloud.qriscloud.org.au/index.php/s/a3KxPawpqkiorST/download"
+_URL = "https://drive.google.com/uc?export=download&id=1xnK3B6K6KekDI55vwJ0vnc2IGoDga9cj"
 _URL_LABELS = "https://raw.githubusercontent.com/AlexOlsen/DeepWeeds/master/labels/labels.csv"
 
 _DESCRIPTION = (
@@ -65,13 +65,9 @@ _CITATION = """\
 class DeepWeeds(tfds.core.GeneratorBasedBuilder):
   """DeepWeeds Image Dataset Class."""
 
-  VERSION = tfds.core.Version("2.0.0")
-  SUPPORTED_VERSIONS = [
-      tfds.core.Version(
-          "1.0.0",
-          tfds_version_to_prepare="c28a63fa9d9fb9ba3cced7052ea243e8884f9bf1"),
-  ]
+  VERSION = tfds.core.Version("3.0.0")
   RELEASE_NOTES = {
+      "3.0.0": "Update download URL.",
       "2.0.0": "Fixes wrong labels in V1.",
   }
 
