@@ -77,7 +77,7 @@ class ImagenetResized(tfds.core.GeneratorBasedBuilder):
   BUILDER_CONFIGS = _make_builder_configs()
 
   def _info(self):
-    names_file = tfds.core.get_tfds_path(_LABELS_FNAME)
+    names_file = tfds.core.tfds_path(_LABELS_FNAME)
     size = self.builder_config.size
     return tfds.core.DatasetInfo(
         builder=self,
