@@ -49,8 +49,8 @@ represented as a dictionary with the following keys:
 
 _CONFIG_VERSION = {
     'matched-frequency': tfds.core.Version('1.0.0'),
-    'threshold-0.7': tfds.core.Version('0.1.1'),
-    'topimages': tfds.core.Version('0.1.1'),
+    'threshold-0.7': tfds.core.Version('1.0.0'),
+    'topimages': tfds.core.Version('1.0.0'),
 }
 _ROOT_URL = 'https://s3-us-west-2.amazonaws.com/imagenetv2public'
 _IMAGENET_V2_URLS = {
@@ -101,7 +101,7 @@ class ImagenetV2(tfds.core.GeneratorBasedBuilder):
   BUILDER_CONFIGS = list(_create_builder_configs())
 
   def _info(self):
-    names_file = tfds.core.get_tfds_path(_IMAGENET_LABELS_FILENAME)
+    names_file = tfds.core.tfds_path(_IMAGENET_LABELS_FILENAME)
     return tfds.core.DatasetInfo(
         builder=self,
         # This is the description that will appear on the datasets page.
