@@ -15,7 +15,6 @@
 
 """The Waymo Open Dataset. See waymo.com/open."""
 
-import io
 import os
 from absl import logging
 import tensorflow.compat.v2 as tf
@@ -253,9 +252,9 @@ def _generate_images_and_annotations(tf_record_file):
   """
   # Go through all frames
   dataset = tf.data.TFRecordDataset(tf_record_file, compression_type="")
-  for data in dataset:
+  for data in tfds.as_numpy(dataset):
     frame = open_dataset.Frame()
-    frame.ParseFromString(bytearray(data.numpy()))  # pytype: disable=wrong-arg-types
+    frame.ParseFromString(bytearray(data))  # pytype: disable=wrong-arg-types
 
     image_and_annotation = {
         "context": {
@@ -281,7 +280,7 @@ def _generate_images_and_annotations(tf_record_file):
 
       camera_name = open_dataset.CameraName.Name.Name(frame_image.name)
       image_and_annotation["camera_" + camera_name] = {
-          "image": io.BytesIO(frame_image.image),
+          "image": frame_image.image,
           "labels": labels
       }
 
