@@ -16,4 +16,8 @@
 """Public API of the proto package."""
 # pylint: disable=g-import-not-at-top,g-importing-member, import-outside-toplevel
 
-from tensorflow_datasets.proto import waymo_dataset_generated_pb2 as waymo_dataset_pb2  # pylint: disable=line-too-long
+try:  # pylint: disable=g-statement-before-imports
+  from waymo_open_dataset import waymo_dataset_pb2
+except ImportError:
+  # If original waymo proto is not found, fallback to the pre-generated proto
+  from tensorflow_datasets.proto import waymo_dataset_generated_pb2 as waymo_dataset_pb2  # pylint: disable=line-too-long
