@@ -16,6 +16,7 @@
 """Structured datasets."""
 
 from tensorflow_datasets.structured.amazon_us_reviews import AmazonUSReviews
+from tensorflow_datasets.structured.e2e_cleaned import E2eCleaned
 from tensorflow_datasets.structured.forest_fires import ForestFires
 from tensorflow_datasets.structured.genomics_ood import GenomicsOod
 from tensorflow_datasets.structured.german_credit_numeric import GermanCreditNumeric
@@ -25,4 +26,5 @@ from tensorflow_datasets.structured.movielens import Movielens
 from tensorflow_datasets.structured.radon import Radon
 from tensorflow_datasets.structured.rock_you import RockYou
 from tensorflow_datasets.structured.titanic import Titanic
+from tensorflow_datasets.structured.wiki_bio import WikiBio
 from tensorflow_datasets.structured.wine_quality import WineQuality
