@@ -13,12 +13,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# Lint as: python3
 """CNN/DailyMail Summarization dataset, non-anonymized version."""
-
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
 import hashlib
 import os
 from absl import logging
@@ -81,36 +76,41 @@ _HIGHLIGHTS = 'highlights'
 _ARTICLE = 'article'
 _SUPPORTED_VERSIONS = [
     # Same data as 0.0.2
-    tfds.core.Version('1.0.0',
-                      'New split API (https://tensorflow.org/datasets/splits)'),
-    # Having the model predict newline separators makes it easier to evaluate
-    # using summary-level ROUGE.
-    tfds.core.Version('2.0.0', 'Separate target sentences with newline.')
+    tfds.core.Version('1.0.0'),
+    tfds.core.Version('2.0.0'),
 ]
-
 # Using cased version.
-_DEFAULT_VERSION = tfds.core.Version('3.0.0', 'Using cased version.')
+_DEFAULT_VERSION = tfds.core.Version('3.0.0')
+
+_RELEASE_NOTES = {
+    '1.0.0': 'New split API (https://tensorflow.org/datasets/splits)',
+    '2.0.0': """
+    Separate target sentences with newline. (Having the model predict newline
+    separators makes it easier to evaluate using summary-level ROUGE.)
+    """,
+    '3.0.0': 'Using cased version.',
+}
 
 
 class CnnDailymailConfig(tfds.core.BuilderConfig):
   """BuilderConfig for CnnDailymail."""
 
-  @tfds.core.disallow_positional_args
-  def __init__(self, text_encoder_config=None, **kwargs):
+  def __init__(self, *, text_encoder_config=None, **kwargs):
     """BuilderConfig for CnnDailymail.
 
     Args:
-      text_encoder_config: `tfds.features.text.TextEncoderConfig`, configuration
-        for the `tfds.features.text.TextEncoder` used for the CnnDailymail
-        (text) features
+      text_encoder_config: `tfds.deprecated.text.TextEncoderConfig`,
+        configuration for the `tfds.deprecated.text.TextEncoder` used for the
+        CnnDailymail (text) features
       **kwargs: keyword arguments forwarded to super.
     """
     super(CnnDailymailConfig, self).__init__(
         version=_DEFAULT_VERSION,
+        release_notes=_RELEASE_NOTES,
         supported_versions=_SUPPORTED_VERSIONS,
         **kwargs)
     self.text_encoder_config = (
-        text_encoder_config or tfds.features.text.TextEncoderConfig())
+        text_encoder_config or tfds.deprecated.text.TextEncoderConfig())
 
 
 def _get_url_hashes(path):
@@ -241,16 +241,16 @@ class CnnDailymail(tfds.core.GeneratorBasedBuilder):
       CnnDailymailConfig(
           name='bytes',
           description=('Uses byte-level text encoding with '
-                       '`tfds.features.text.ByteTextEncoder`'),
-          text_encoder_config=tfds.features.text.TextEncoderConfig(
-              encoder=tfds.features.text.ByteTextEncoder()),
+                       '`tfds.deprecated.text.ByteTextEncoder`'),
+          text_encoder_config=tfds.deprecated.text.TextEncoderConfig(
+              encoder=tfds.deprecated.text.ByteTextEncoder()),
       ),
       CnnDailymailConfig(
           name='subwords32k',
-          description=('Uses `tfds.features.text.SubwordTextEncoder` with '
+          description=('Uses `tfds.deprecated.text.SubwordTextEncoder` with '
                        '32k vocab size'),
-          text_encoder_config=tfds.features.text.TextEncoderConfig(
-              encoder_cls=tfds.features.text.SubwordTextEncoder,
+          text_encoder_config=tfds.deprecated.text.TextEncoderConfig(
+              encoder_cls=tfds.deprecated.text.SubwordTextEncoder,
               vocab_size=2**15),
       ),
   ]
