@@ -15,42 +15,52 @@
 
 """Tests for c4 dataset module."""
 
-import six
-
 from tensorflow_datasets import testing
 from tensorflow_datasets.text import c4
 
 
 class C4Test(testing.DatasetBuilderTestCase):
   DATASET_CLASS = c4.C4
-  # 10k shards take make the test too slow.
-  c4._DEFAULT_NUM_SHARDS = 1
-  # GzipFile + GFile and TextIOWrapper are broken for py2.
-  BUILDER_CONFIG_NAMES_TO_TEST = ["en"] if six.PY3 else []
+  BUILDER_CONFIG_NAMES_TO_TEST = ["en"]
 
   DL_EXTRACT_RESULT = {
       "wet_path_urls": ["wet_urls.txt"],
       "wet_files": ["cc_0.warc.wet.gz", "cc_1.warc.wet.gz"],
+      "manual_wet_paths": {},
       "https://commoncrawl.s3.amazonaws.com/cc_0.warc.wet.gz":
           "cc_0.warc.wet.gz",
       "https://commoncrawl.s3.amazonaws.com/cc_1.warc.wet.gz":
           "cc_1.warc.wet.gz",
-      "badwords": "badwords.txt",
+      "badwords": {"en": "badwords.txt"},
   }
   SPLITS = {
-      "train": 1,
-      "validation": 1,
+      "train": 2,
+      "validation": 2,
   }
 
 
 class C4NoCleanTest(C4Test):
-  # GzipFile + GFile and TextIOWrapper are broken for py2.
-  BUILDER_CONFIG_NAMES_TO_TEST = ["en.noclean"] if six.PY3 else []
+  BUILDER_CONFIG_NAMES_TO_TEST = ["en.noclean"]
   SPLITS = {
-      "train": 3,
-      "validation": 1,
+      "train": 4,
+      "validation": 2,
   }
 
 
+class C4MultilingualTest(C4Test):
+  BUILDER_CONFIG_NAMES_TO_TEST = ["multilingual"]
+  for config in c4.C4.BUILDER_CONFIGS:
+    if config.name == "multilingual":
+      config.languages = ["en", "de"]
+
+  SPLITS = {
+      "en": 1,
+      "en-validation": 1,
+      "de": 1,
+      "de-validation": 1,
+      "und": 1,
+      "und-validation": 1,
+  }
+
 if __name__ == "__main__":
   testing.test_main()
